[Erp5-report] r22329 - /erp5/trunk/products/ERP5/tests/testProductionOrder.py

nobody at svn.erp5.org nobody at svn.erp5.org
Mon Jul 7 23:33:22 CEST 2008


Author: luke
Date: Mon Jul  7 23:33:21 2008
New Revision: 22329

URL: http://svn.erp5.org?rev=22329&view=rev
Log:
 - method name rename, docstring addition/update

Modified:
    erp5/trunk/products/ERP5/tests/testProductionOrder.py

Modified: erp5/trunk/products/ERP5/tests/testProductionOrder.py
URL: http://svn.erp5.org/erp5/trunk/products/ERP5/tests/testProductionOrder.py?rev=22329&r1=22328&r2=22329&view=diff
==============================================================================
--- erp5/trunk/products/ERP5/tests/testProductionOrder.py (original)
+++ erp5/trunk/products/ERP5/tests/testProductionOrder.py Mon Jul  7 23:33:21 2008
@@ -103,10 +103,10 @@
                                                portal_type='Category',
                                                id=category_id)
 
-  def stepCreateBrandCompositionVariatedComponent1(self,sequence=None, sequence_list=None, \
+  def stepCreateColourSizeVariatedComponent1(self,sequence=None, sequence_list=None, \
                                     **kw):
     """
       Create a resource with no variation
     """
     portal = self.getPortal()
     resource_module = portal.getDefaultModule(self.component_portal_type)
@@ -306,6 +306,9 @@
 
   def stepSetTransformationTransformedResourceQuantityMatrix(self, sequence=None, sequence_list=None,
                                **kw):
+    """
+      Fills variation based quantity matrix
+    """
 
     transformation_transformed_resource = sequence.get('transformation_transformed_resource')
     colour_count = size_count = 0
@@ -327,6 +330,9 @@
 
   def stepSetTransformationTransformedResourceVariationMatrix(self, sequence=None, sequence_list=None,
                                **kw):
+    """
+      Fills variation matrix
+    """
 
     transformation_transformed_resource = sequence.get('transformation_transformed_resource')
     colour_count = size_count = 0
@@ -348,6 +354,9 @@
 
   def stepSetOrderLineQuantityMatrix(self, sequence=None, sequence_list=None,
                                **kw):
+    """
+      Fills variation based quantity matrix
+    """
     order_line = sequence.get('order_line')
     colour_count = size_count = 0
 
@@ -377,6 +386,9 @@
 
   def stepSetTransformationTransformedResourceVariation(self, sequence=None, sequence_list=None,
                                **kw):
+    """
+      Fills categories of variation
+    """
 
     transformation_transformed_resource = sequence.get('transformation_transformed_resource')
 
@@ -387,6 +399,9 @@
 
   def stepSetTransformationVariation(self, sequence=None, sequence_list=None,
                                **kw):
+    """
+      Fills categories of variation
+    """
 
     transformation = sequence.get('transformation')
 
@@ -513,7 +528,7 @@
 
   def stepCreateOrder(self, sequence=None, sequence_list=None, **kw):
     """
-      Create a empty order
+      Create a filled order
     """
     portal = self.getPortal()
     order_module = portal.getDefaultModule(portal_type=self.order_portal_type)
@@ -531,7 +546,7 @@
 
   def stepCreateOrderLine(self, sequence=None, sequence_list=None, **kw):
     """
       Create a empty order line
     """
     order = sequence.get('order')
     order_line = order.newContent(portal_type=self.order_line_portal_type)
@@ -1696,7 +1711,7 @@
                       CreateSourcingSC \
                       Tic \
                       CreateColourSizeVariatedResource \
-                      CreateBrandCompositionVariatedComponent1 \
+                      CreateColourSizeVariatedComponent1 \
                       Tic \
                       CreateEmptyTransformation \
                       FillTransformationWithResource \
@@ -103,10 +103,10 @@
                                     **kw):
     """
-      Create a resource with no variation
+      Create a resource with colour and size variation
     """
     portal = self.getPortal()
@@ -531,7 +546,7 @@
   def stepCreateOrderLine(self, sequence=None, sequence_list=None, **kw):
     """
-      Create a empty order line
+      Create a filled order line
     """
     order = sequence.get('order')




More information about the Erp5-report mailing list